@@ -162,7 +162,7 @@ class DBMonitorProvider(object):
 
     @classmethod
     @transaction.commit_on_success
-    def register_backup(self, databaseinfra, start_at, end_at, size, status, type):
+    def register_backup(self, databaseinfra, start_at, end_at, size, status, type, error):
         
         from backup.models import BackupInfo
         
@@ -180,7 +180,9 @@ class DBMonitorProvider(object):
             status_backup = 'COMPLETO'
         else:                    
             status_backup = 'FALHA'
-            
+        
+        if error is None:
+            error = ''    
         
         backup_dict = {
         'database_id': infraattr.dbmonitor_databaseinfra,
@@ -190,7 +192,7 @@ class DBMonitorProvider(object):
         'bytes_saida': size,
         'status_backup': status_backup,
         'tipo_backup': tipo_backup,
-        'info_adicional': '',
+        'info_adicional': error,
         'compactado': 'false'
         }
         
@@ -200,7 +202,7 @@ class DBMonitorProvider(object):
             """ % backup_dict
         else:
             sql = """INSERT INTO mongodb_backup (database_id, data_inicio, data_fim, segundos_decorrido, bytes_saida, status_backup, tipo_backup, info_adicional, compactado)
-                     VALUES (%(database_id)s, '%(data_inicio)s', '%(data_fim)s', %(segundos_decorrido)s, %(bytes_saida)s, '%(status_backup)s', '%(tipo_backup)s', '%(info_adicional)s', %(compactado)s)
+                     VALUES (%(database_id)s, '%(data_inicio)s', '%(data_fim)s', %(segundos_decorrido)s, %(bytes_saida)s, '%(status_backup)s', '%(tipo_backup)s', "%(info_adicional)s", %(compactado)s)
             """ % backup_dict
         try:
             
